@@ -151,6 +151,12 @@ instance Arbitrary ThirtyTwoBitTimeStamp where
 instance Arbitrary ThirtyTwoBitDuration where
     arbitrary = liftM ThirtyTwoBitDuration arbitrary
 
+instance Arbitrary NotationName where
+    arbitrary = liftM NotationName arbitrary
+
+instance Arbitrary NotationValue where
+    arbitrary = liftM NotationValue arbitrary
+
 -- FIXME: this should be elsewhere
 instance Arbitrary a => Arbitrary (NE.NonEmpty a) where
     arbitrary = NE.fromList `liftM` listOf1 arbitrary
