@@ -1,5 +1,6 @@
 -- CFB.hs: OpenPGP (RFC4880) CFB mode
--- Copyright © 2013 Daniel Kahn Gillmor and Clint Adams
+-- Copyright © 2013-2015  Clint Adams
+-- Copyright © 2013  Daniel Kahn Gillmor
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -26,7 +27,7 @@ decryptOpenPGPCfb sa ciphertext keydata = do
     bc <- mkBCipher sa keydata
     let nonce = decrypt1 ciphertext bc
     cleartext <- decrypt2 ciphertext bc
-    if nonceCheck bc nonce then return cleartext else fail "Session key quickcheck failed"
+    if nonceCheck bc nonce then return cleartext else Left "Session key quickcheck failed"
     where
         decrypt1 :: B.ByteString -> BCipher -> B.ByteString
         decrypt1 ct (BCipher cipher) = cdecrypt sa cipher nullIV (B.take (blockSize cipher + 2) ct)
@@ -38,7 +39,7 @@ decrypt Plaintext ciphertext _ = return ciphertext
 decrypt sa ciphertext keydata = do
     bc <- mkBCipher sa keydata
     let (nonce, cleartext) = B.splitAt (bcBlockSize bc + 2) (decrypt' ciphertext bc)
-    if nonceCheck bc nonce then return cleartext else fail "Session key quickcheck failed"
+    if nonceCheck bc nonce then return cleartext else Left "Session key quickcheck failed"
     where
         decrypt' :: B.ByteString -> BCipher -> B.ByteString
         decrypt' ct (BCipher cipher) = cdecrypt sa cipher nullIV ct
@@ -66,11 +67,11 @@ paddedCfbDecrypt cipher iv ciphertext = B.take (B.length ciphertext) (cfbDecrypt
         padded = ciphertext `B.append` B.pack (replicate (blockSize cipher - (B.length ciphertext `mod` blockSize cipher)) 0)
 
 mkBCipher :: ToSecureMem b => SymmetricAlgorithm -> b -> Either String BCipher
-mkBCipher Plaintext = const (fail "this shouldn't have happened") -- FIXME: orphan instance?
-mkBCipher IDEA = const (fail "IDEA not yet implemented") -- FIXME: IDEA
-mkBCipher ReservedSAFER = const (fail "SAFER not implemented") -- FIXME: or not?
-mkBCipher ReservedDES = const (fail "DES not implemented") -- FIXME: or not?
-mkBCipher (OtherSA _) = const (fail "Unknown, unimplemented symmetric algorithm")
+mkBCipher Plaintext = const (Left "this shouldn't have happened") -- FIXME: orphan instance?
+mkBCipher IDEA = const (Left "IDEA not yet implemented") -- FIXME: IDEA
+mkBCipher ReservedSAFER = const (Left "SAFER not implemented") -- FIXME: or not?
+mkBCipher ReservedDES = const (Left "DES not implemented") -- FIXME: or not?
+mkBCipher (OtherSA _) = const (Left "Unknown, unimplemented symmetric algorithm")
 mkBCipher CAST5 = return . BCipher . (ciph :: ToSecureMem b => b -> CNC.CAST128)
 mkBCipher Twofish = return . BCipher . (ciph :: ToSecureMem b => b -> CNC.TWOFISH)
 mkBCipher TripleDES = return . BCipher . (ciph :: ToSecureMem b => b -> CC.DES_EDE3)
