@@ -1,5 +1,5 @@
 -- Expirations.hs: OpenPGP (RFC4880) expiration checking
--- Copyright © 2014  Clint Adams
+-- Copyright © 2014-2015  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -9,7 +9,6 @@ module Codec.Encryption.OpenPGP.Expirations (
 ) where
 
 import Control.Lens ((&), (^.), _1)
-import Data.List (sort)
 import Data.Time.Clock (UTCTime)
 import Data.Time.Clock.POSIX (posixSecondsToUTCTime)
 
@@ -20,11 +19,11 @@ isTKTimeValid :: UTCTime -> TK -> Bool
 isTKTimeValid ct key = ct >= keyCreationTime && ct < keyExpirationTime
     where
         keyCreationTime = key^.tkKey._1.timestamp & posixSecondsToUTCTime . realToFrac
-        keyExpirationTime = posixSecondsToUTCTime . realToFrac . ((+) (key^.tkKey._1.timestamp)) . newest . concatMap getKeyExpirationTimesFromSignature $ (concatMap snd (key^.tkUIDs) ++ concatMap snd (key^.tkUAts))
+        keyExpirationTime = posixSecondsToUTCTime . realToFrac . ((key^.tkKey._1.timestamp & unThirtyTwoBitTimeStamp) +) . unThirtyTwoBitDuration . newest . concatMap getKeyExpirationTimesFromSignature $ (concatMap snd (key^.tkUIDs) ++ concatMap snd (key^.tkUAts))
 	newest [] = maxBound
-	newest xs = last (sort xs)
+	newest xs = maximum xs
 
-getKeyExpirationTimesFromSignature :: SignaturePayload -> [TimeStamp]
+getKeyExpirationTimesFromSignature :: SignaturePayload -> [ThirtyTwoBitDuration]
 getKeyExpirationTimesFromSignature (SigV4 _ _ _ xs _ _ _) = map (\(SigSubPacket _ (KeyExpirationTime x)) -> x) $ filter isKET xs
     where
         isKET (SigSubPacket _ (KeyExpirationTime _)) = True
