@@ -1,5 +1,5 @@
 -- Internal.hs: private utility functions
--- Copyright © 2012-2014  Clint Adams
+-- Copyright © 2012-2015  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -26,8 +26,8 @@ import qualified Crypto.PubKey.DSA as DSA
 import qualified Crypto.PubKey.RSA as RSA
 
 import Data.Bits (testBit, shiftL, shiftR, (.&.))
-import Data.ByteString (ByteString)
-import qualified Data.ByteString as B
+import Data.ByteString.Lazy (ByteString)
+import qualified Data.ByteString.Lazy as BL
 import Data.List (find, mapAccumR, unfoldr)
 import Data.Word (Word8, Word16)
 
@@ -35,18 +35,18 @@ import Codec.Encryption.OpenPGP.Types
 
 countBits :: ByteString -> Word16
 countBits bs
-    | B.null bs = 0
-    | otherwise = fromIntegral (B.length bs * 8) - fromIntegral (go (B.head bs) 7)
+    | BL.null bs = 0
+    | otherwise = fromIntegral (BL.length bs * 8) - fromIntegral (go (BL.head bs) 7)
     where
         go :: Word8 -> Int -> Word8
         go _ 0 = 7
         go n b = if testBit n b then 7 - fromIntegral b else go n (b-1)
 
 beBSToInteger :: ByteString -> Integer
-beBSToInteger = sum . snd . mapAccumR (\acc x -> (acc + 8, fromIntegral x `shiftL` acc)) 0 . B.unpack
+beBSToInteger = sum . snd . mapAccumR (\acc x -> (acc + 8, fromIntegral x `shiftL` acc)) 0 . BL.unpack
 
 integerToBEBS :: Integer -> ByteString
-integerToBEBS = B.pack . reverse . unfoldr (\x -> if x == 0 then Nothing else Just ((fromIntegral x :: Word8) .&. 0xff, x `shiftR` 8))
+integerToBEBS = BL.pack . reverse . unfoldr (\x -> if x == 0 then Nothing else Just ((fromIntegral x :: Word8) .&. 0xff, x `shiftR` 8))
 
 data PktStreamContext = PktStreamContext { lastLD :: Pkt
                       , lastUIDorUAt :: Pkt
@@ -76,8 +76,8 @@ hashDescr DeprecatedMD5 = Right hashDescrMD5
 hashDescr x = Left $ "Unknown hash problem: " ++ show x
 
 pubkeyToMPIs :: PKey -> [MPI]
-pubkeyToMPIs (RSAPubKey k) = [MPI (RSA.public_n k), MPI (RSA.public_e k)]
-pubkeyToMPIs (DSAPubKey k) = [
+pubkeyToMPIs (RSAPubKey (RSA_PublicKey k)) = [MPI (RSA.public_n k), MPI (RSA.public_e k)]
+pubkeyToMPIs (DSAPubKey (DSA_PublicKey k)) = [
                                pkParams DSA.params_p
                              , pkParams DSA.params_q
                              , pkParams DSA.params_g
@@ -107,7 +107,7 @@ sigHA (SigV3 _ _ _ _ ha _ _) = Just ha
 sigHA (SigV4 _ _ ha _ _ _ _) = Just ha
 sigHA _ = Nothing -- this includes v2 sigs, which don't seem to be specified in the RFCs but exist in the wild
 
-sigCT :: SignaturePayload -> Maybe TimeStamp
+sigCT :: SignaturePayload -> Maybe ThirtyTwoBitTimeStamp
 sigCT (SigV3 _ ct _ _ _ _ _) = Just ct
 sigCT (SigV4 _ _ _ hsubs _ _ _) = fmap (\(SigSubPacket _ (SigCreationTime i)) -> i) (find isSigCreationTime hsubs)
     where
