@@ -1,5 +1,5 @@
 -- KeyInfo.hs: OpenPGP (RFC4880) fingerprinting methods
--- Copyright © 2012-2014  Clint Adams
+-- Copyright © 2012-2015  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -18,8 +18,8 @@ import Data.List (unfoldr)
 
 import Codec.Encryption.OpenPGP.Types
 
-pubkeySize (RSAPubKey x) = Right (RSA.public_size x * 8)
-pubkeySize (DSAPubKey x) = Right (bitcount . DSA.params_p . DSA.public_params $ x)
+pubkeySize (RSAPubKey (RSA_PublicKey x)) = Right (RSA.public_size x * 8)
+pubkeySize (DSAPubKey (DSA_PublicKey x)) = Right (bitcount . DSA.params_p . DSA.public_params $ x)
 pubkeySize (ElGamalPubKey x) = Right (bitcount $ head x)
 pubkeySize x = Left $ "Unable to calculate size of " ++ show x
 
