@@ -1,5 +1,5 @@
 -- KeySelection.hs: OpenPGP (RFC4880) ways to ask for keys
--- Copyright © 2014  Clint Adams
+-- Copyright © 2014-2015  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -10,7 +10,7 @@ module Codec.Encryption.OpenPGP.KeySelection (
  , parseFingerprint
 ) where
 
-import qualified Data.ByteString as B
+import qualified Data.ByteString.Lazy as BL
 import Codec.Encryption.OpenPGP.Internal (integerToBEBS)
 import Codec.Encryption.OpenPGP.Types
 import Control.Applicative (optional, (<$>), (*>))
@@ -31,5 +31,5 @@ hexPrefix = optional (asciiCI "0x")
 hexen :: Int -> Parser Text
 hexen n = T.pack <$> count n (satisfy (inClass "A-F0-9"))
 
-hexes :: Parser B.ByteString
+hexes :: Parser BL.ByteString
 hexes = integerToBEBS <$> hexadecimal
