@@ -1,5 +1,5 @@
 -- KeyringParser.hs: OpenPGP (RFC4880) transferable keys parsing
--- Copyright © 2012-2014  Clint Adams
+-- Copyright © 2012-2015  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -26,6 +26,7 @@ module Codec.Encryption.OpenPGP.KeyringParser (
 
 import Control.Applicative (many, (<$>), (<|>))
 import Data.Monoid (Monoid, (<>), mconcat)
+import Data.Text (Text)
 
 import Codec.Encryption.OpenPGP.Types
 import Data.Conduit.OpenPGP.Keyring.Instances ()
@@ -37,7 +38,7 @@ parseAChunk op a (cr, Nothing) = (inspect (feed (mconcat (map snd cr) <> a) op),
 parseAChunk _ a (_, Just (_, p)) = (inspect (feed a p), [])
 
 finalizeParsing :: Monoid s => ([(r, s)], Maybe (Maybe (r -> r), Parser s r)) -> (([(r, s)], Maybe (Maybe (r -> r), Parser s r)), [r])
-finalizeParsing ([], Nothing) = error $ "Unexpected finalization failure"
+finalizeParsing ([], Nothing) = error "Unexpected finalization failure"
 finalizeParsing (cr, Nothing) = (([], Nothing), map fst cr)
 finalizeParsing (_, Just (_, p)) = finalizeParsing (inspect (feedEof p))
 
@@ -45,21 +46,21 @@ parseTK :: Bool -> Parser [Pkt] (Maybe TK)
 parseTK True = publicTK True <|> secretTK True
 parseTK False = publicTK False <|> secretTK False <|> brokenTK 6 <|> brokenTK 5
 
-data UidOrUat = I String | A [UserAttrSubPacket]
+data UidOrUat = I Text | A [UserAttrSubPacket]
     deriving Show
 
-splitUs :: [(UidOrUat, [SignaturePayload])] -> ([(String, [SignaturePayload])], [([UserAttrSubPacket], [SignaturePayload])])
+splitUs :: [(UidOrUat, [SignaturePayload])] -> ([(Text, [SignaturePayload])], [([UserAttrSubPacket], [SignaturePayload])])
 splitUs us = (is, as)
     where
         is = map unI (filter isI us)
         as = map unA (filter isA us)
-	isI ((I _), _) = True
+	isI (I _, _) = True
 	isI _ = False
-	isA ((A _), _) = True
+	isA (A _, _) = True
 	isA _ = False
-	unI ((I x), y) = (x, y)
+	unI (I x, y) = (x, y)
 	unI x = error $ "unI should never be called on " ++ show x
-	unA ((A x), y) = (x, y)
+	unA (A x, y) = (x, y)
 	unA x = error $ "unA should never be called on " ++ show x
 
 publicTK, secretTK :: Bool -> Parser [Pkt] (Maybe TK)
@@ -68,7 +69,7 @@ publicTK intolerant = do
     pkpsigs <- concatMany (signature intolerant [KeyRevocationSig,SignatureDirectlyOnAKey])
     (uids, uats) <- fmap splitUs (many (signedUID intolerant <|> signedUAt intolerant)) -- FIXME: require >=1 uid if intolerant
     subs <- concatMany (pubsub intolerant)
-    return $! Just (TK pkp pkpsigs uids uats subs)
+    return $ Just (TK pkp pkpsigs uids uats subs)
         where
             pubsub True = signedOrRevokedPubSubkey True
             pubsub False = signedOrRevokedPubSubkey False <|> brokenPubSubkey
@@ -77,7 +78,7 @@ secretTK intolerant = do
     skpsigs <- concatMany (signature intolerant [KeyRevocationSig,SignatureDirectlyOnAKey])
     (uids, uats) <- fmap splitUs (many (signedUID intolerant <|> signedUAt intolerant)) -- FIXME: require >=1 uid if intolerant?
     subs <- concatMany (secsub intolerant)
-    return $! Just (TK skp skpsigs uids uats subs)
+    return $ Just (TK skp skpsigs uids uats subs)
         where
             secsub True = rawOrSignedOrRevokedSecSubkey True
             secsub False = rawOrSignedOrRevokedSecSubkey False <|> brokenSecSubkey
@@ -105,7 +106,7 @@ pkPayload = do [PublicKeyPkt p] <- satisfy isPKP
         isPKP _ = False
 
 signature :: Bool -> [SigType] -> Parser [Pkt] [SignaturePayload]
-signature intolerant rts = if intolerant then signature' else (signature' <|> brokensig')
+signature intolerant rts = if intolerant then signature' else signature' <|> brokensig'
     where
         signature' = do [SignaturePkt sp] <- satisfy (isSP intolerant)
                         return $! (if intolerant then id else filter isSP') [sp]
