@@ -1,5 +1,5 @@
 -- S2K.hs: OpenPGP (RFC4880) string-to-key conversion
--- Copyright © 2013  Clint Adams
+-- Copyright © 2013-2015  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -19,8 +19,8 @@ import qualified Data.ByteString.Lazy as BL
 
 string2Key :: S2K -> Int -> BL.ByteString -> B.ByteString
 string2Key (Simple ha) ksz bs = B.take (fromIntegral ksz) $ hashpp (hf ha) ksz bs
-string2Key (Salted ha salt) ksz bs = string2Key (Simple ha) ksz (BL.append (BL.fromChunks [salt]) bs)
-string2Key (IteratedSalted ha salt cnt) ksz bs = string2Key (Simple ha) ksz (BL.take (fromIntegral cnt) . BL.cycle $ BL.append (BL.fromStrict salt) bs)
+string2Key (Salted ha salt) ksz bs = string2Key (Simple ha) ksz (BL.append (BL.fromStrict (unSalt salt)) bs)
+string2Key (IteratedSalted ha salt cnt) ksz bs = string2Key (Simple ha) ksz (BL.take (fromIntegral cnt) . BL.cycle $ BL.append (BL.fromStrict (unSalt salt)) bs)
 string2Key _ _ _ = error "FIXME: unimplemented S2K type"
 
 hf :: HashAlgorithm -> BL.ByteString -> B.ByteString
