@@ -15,13 +15,12 @@ import Codec.Encryption.OpenPGP.BlockCipher (saBlockSize, keySize)
 import Codec.Encryption.OpenPGP.CFB (decryptNoNonce, encryptNoNonce)
 import Codec.Encryption.OpenPGP.Serialize (getSecretKey)
 import Codec.Encryption.OpenPGP.S2K (skesk2Key, string2Key)
-import Control.Monad ((>=>))
 import qualified Crypto.Hash.SHA1 as SHA1
 import Crypto.Random (createEntropyPool, cprgCreate, cprgGenerateWithEntropy, SystemRNG)
 import qualified Data.ByteString as B
 import qualified Data.ByteString.Lazy as BL
 import Data.Binary (put)
-import Data.Binary.Get (getLazyByteString, remaining, getWord16be, runGetOrFail)
+import Data.Binary.Get (getRemainingLazyByteString, getWord16be, runGetOrFail)
 import Data.Binary.Put (runPut)
 import Data.Bifunctor (bimap)
 import qualified Crypto.PubKey.RSA as R
@@ -48,7 +47,7 @@ decryptSKA (pkp, SUSSHA1 sa s2k iv payload) pp = do
     let checksum = sum . map fromIntegral . B.unpack . B.take (B.length p - 20) $ p
     return $ SUUnencrypted s checksum  -- FIXME: is this the correct checksum?
     where
-        getSecretKeyAndChecksum p = bimap (\(_,_,x) -> x) (\(_,_,x) -> x) (runGetOrFail (getSecretKey pkp >>= \sk -> remaining >>= (getLazyByteString >=> \csum -> return (sk, csum))) (BL.fromStrict p))
+        getSecretKeyAndChecksum p = bimap (\(_,_,x) -> x) (\(_,_,x) -> x) (runGetOrFail (getSecretKey pkp >>= \sk -> getRemainingLazyByteString >>= \csum -> return (sk, csum)) (BL.fromStrict p))
 decryptSKA _ _ = Left "Unexpected codepath"
 
 -- |generates pseudo-random salt and IV
