@@ -8,9 +8,9 @@ module Codec.Encryption.OpenPGP.Serialize (
  , getSecretKey
 ) where
 
-import Control.Applicative ((<$>),(<*>), many, some)
+import Control.Applicative ((<$>), many, some)
 import Control.Lens ((^.), _1)
-import Control.Monad (guard, liftM, mplus, replicateM, replicateM_)
+import Control.Monad (guard, liftM, replicateM, replicateM_)
 import qualified Crypto.PubKey.RSA as R
 import qualified Crypto.PubKey.DSA as D
 import Data.Bits ((.&.), (.|.), shiftL, shiftR, testBit)
@@ -20,7 +20,7 @@ import qualified Data.ByteString.Lazy as BL
 import Data.List (mapAccumL)
 import qualified Data.List.NonEmpty as NE
 import Data.Binary (Binary, get, put)
-import Data.Binary.Get (Get, getWord8, getWord16be, getWord32be, getByteString, getLazyByteString, getWord16le, runGetOrFail, remaining, ByteOffset)
+import Data.Binary.Get (Get, getByteString, getLazyByteString, getRemainingLazyByteString, getWord8, getWord16be, getWord32be, getWord16le, runGetOrFail, ByteOffset)
 import Data.Binary.Put (Put, putWord8, putWord16be, putWord32be, putByteString, putLazyByteString, putWord16le, runPut)
 import qualified Data.Foldable as F
 import Data.Monoid (mempty)
@@ -215,9 +215,9 @@ getSigSubPacket = do
                        flags <- getLazyByteString 4
                        nl <- getWord16be
                        vl <- getWord16be
-                       nd <- getLazyByteString (fromIntegral nl)
+                       nn <- getLazyByteString (fromIntegral nl)
                        nv <- getLazyByteString (fromIntegral vl)
-                       return $ SigSubPacket crit (NotationData (bsToFFSet flags) nd nv)
+                       return $ SigSubPacket crit (NotationData (bsToFFSet flags) (NotationName nn) (NotationValue nv))
             | pt == 21 = do
                        ha <- replicateM (fromIntegral (l - 1)) get
                        return $ SigSubPacket crit (PreferredHashAlgorithms ha)
@@ -302,17 +302,17 @@ putSigSubPacket (SigSubPacket crit (PreferredSymmetricAlgorithms ess)) = do
 putSigSubPacket (SigSubPacket crit (RevocationKey rclass algid fp)) = do
     putSubPacketLength 23
     putSigSubPacketType crit 12
-    putLazyByteString . ffSetToFixedLengthBS 1 $ Set.insert (RClOther 0) rclass
+    putLazyByteString . ffSetToFixedLengthBS (1 :: Int) $ Set.insert (RClOther 0) rclass
     put algid
     putLazyByteString (unTOF fp) -- 20 octets
 putSigSubPacket (SigSubPacket crit (Issuer keyid)) = do
     putSubPacketLength 9
     putSigSubPacketType crit 16
     putLazyByteString (unEOKI keyid) -- 8 octets
-putSigSubPacket (SigSubPacket crit (NotationData nfs nn nv)) = do
+putSigSubPacket (SigSubPacket crit (NotationData nfs (NotationName nn) (NotationValue nv))) = do
     putSubPacketLength . fromIntegral $ (9 + BL.length nn + BL.length nv)
     putSigSubPacketType crit 20
-    putLazyByteString . ffSetToFixedLengthBS 4 $ nfs
+    putLazyByteString . ffSetToFixedLengthBS (4 :: Int) $ nfs
     putWord16be . fromIntegral . BL.length $ nn
     putWord16be . fromIntegral . BL.length $ nv
     putLazyByteString nn
@@ -375,10 +375,7 @@ putSigSubPacket (SigSubPacket crit (EmbeddedSignature sp)) = do
     putSubPacketLength . fromIntegral $ (1 + BL.length spb)
     putSigSubPacketType crit 32
     putLazyByteString spb
-putSigSubPacket (SigSubPacket crit (UserDefinedSigSub ptype payload)) = do
-    putSubPacketLength . fromIntegral $ (1 + BL.length payload)
-    putSigSubPacketType crit ptype
-    putLazyByteString payload
+putSigSubPacket (SigSubPacket crit (UserDefinedSigSub ptype payload)) = putSigSubPacket (SigSubPacket crit (OtherSigSub ptype payload))
 putSigSubPacket (SigSubPacket crit (OtherSigSub ptype payload)) = do
     putSubPacketLength . fromIntegral $ (1 + BL.length payload)
     putSigSubPacketType crit ptype
@@ -415,7 +412,9 @@ putSigSubPacketType False sst = putWord8 sst
 putSigSubPacketType True sst = putWord8 (sst .|. 0x80)
 
 bsToFFSet :: FutureFlag a => ByteString -> Set a
-bsToFFSet bs = Set.fromAscList .  concat . snd $ mapAccumL (\acc y -> (acc+8, concatMap (\x -> if y .&. shiftR 128 x == shiftR 128 x then [toFFlag (acc + x)] else []) [0..7])) 0 (BL.unpack bs)
+bsToFFSet bs = Set.fromAscList .  concat . snd $ mapAccumL (\acc y -> (acc+8, concatMap (shifty acc y) [0..7])) 0 (BL.unpack bs)
+    where
+        shifty acc y x = [toFFlag (acc + x) | y .&. shiftR 128 x == shiftR 128 x]
 
 ffSetToFixedLengthBS :: (Integral a, FutureFlag b) => a -> Set b -> ByteString
 ffSetToFixedLengthBS len ffs = BL.take (fromIntegral len) (BL.append (ffSetToBS ffs) (BL.pack (replicate 5 0)))
@@ -480,8 +479,7 @@ getS2K = getS2K' =<< getWord8
                           count <- getWord8
                           return $ IteratedSalted (toFVal ha) (Salt salt) (decodeIterationCount count)
             | otherwise = do
-                          len <- remaining
-                          bs <- getLazyByteString len
+                          bs <- getRemainingLazyByteString
                           return $ OtherS2K t bs
 
 putS2K :: S2K -> Put
@@ -511,8 +509,7 @@ getPacketTypeAndPayload = do
                        2 -> do len <- getWord32be
                                bs <- getLazyByteString (fromIntegral len)
                                return (t, bs)
-                       3 -> do len <- remaining
-                               bs <- getLazyByteString len
+                       3 -> do bs <- getRemainingLazyByteString
                                return (t, bs)
                        _ -> error "This should never happen (getPacketTypeAndPayload/0x00)."
         0x40 -> do
@@ -533,15 +530,13 @@ getPkt = do
             | t == 1 = do
                           pv <- getWord8
                           eokeyid <- getLazyByteString 8
-                          pkalgo <- getWord8
-                          remainder <- remaining
-                          mpib <- getLazyByteString remainder
+                          pka <- getWord8
+                          mpib <- getRemainingLazyByteString
                           case runGetOrFail (some getMPI) mpib of
                               Left (_, _, e) -> fail ("PKESK MPIs " ++ e)
-                              Right (_, _, sk) -> return $ PKESKPkt pv (EightOctetKeyId eokeyid) (toFVal pkalgo) (NE.fromList sk)
+                              Right (_, _, sk) -> return $ PKESKPkt pv (EightOctetKeyId eokeyid) (toFVal pka) (NE.fromList sk)
             | t == 2 = do
-                          remainder <- remaining
-                          bs <- getLazyByteString remainder
+                          bs <- getRemainingLazyByteString
                           case runGetOrFail get bs of
                               Left (_, _, e) -> fail ("signature packet " ++ e)
                               Right (_, _, sp) -> return $ SignaturePkt sp
@@ -549,8 +544,7 @@ getPkt = do
                           pv <- getWord8
                           symalgo <- getWord8
                           s2k <- getS2K
-                          remainder <- remaining
-                          esk <- getLazyByteString remainder
+                          esk <- getRemainingLazyByteString
                           return $ SKESKPkt pv (toFVal symalgo) s2k (if BL.null esk then Nothing else Just esk)
             | t == 4 = do
                           pv <- getWord8
@@ -630,7 +624,7 @@ getUserAttrSubPacket = do
             getUserAttrSubPacket' :: Word8 -> ByteOffset -> Get UserAttrSubPacket
             getUserAttrSubPacket' t l
                 | t == 1 = do
-                              ihlen <- getWord16le
+                              _ <- getWord16le -- ihlen
                               hver <- getWord8 -- should be 1
                               iformat <- getWord8
                               nuls <- getLazyByteString 12 -- should be NULs
@@ -658,19 +652,18 @@ putUserAttrSubPacket ua = do
             putLazyByteString bs
 
 putPkt :: Pkt -> Put
-putPkt (PKESKPkt pv eokeyid pkalgo mpis) = do
+putPkt (PKESKPkt pv eokeyid pka mpis) = do
     putWord8 (0xc0 .|. 1)
     let bsk = runPut $ F.mapM_ put mpis
     putPacketLength . fromIntegral $ 10 + BL.length bsk
     putWord8 pv -- must be 3
     putLazyByteString (unEOKI eokeyid) -- must be 8 octets
-    putWord8 $ fromIntegral . fromFVal $ pkalgo
+    putWord8 $ fromIntegral . fromFVal $ pka
     putLazyByteString bsk
 putPkt (SignaturePkt sp) = do
     putWord8 (0xc0 .|. 2)
     let bs = runPut $ put sp
-    putPacketLength . fromIntegral . BL.length $ bs
-    putLazyByteString bs
+    putLengthThenPayload bs
 putPkt (SKESKPkt pv symalgo s2k mesk) = do
     putWord8 (0xc0 .|. 3)
     let bs2k = fromS2K s2k
@@ -689,38 +682,31 @@ putPkt (OnePassSignaturePkt pv sigtype ha pka skeyid nested) = do
                 putWord8 $ fromIntegral . fromFVal $ pka
                 putLazyByteString (unEOKI skeyid)
                 putWord8 . fromIntegral . fromEnum $ not nested -- FIXME: what do other values mean?
-    putPacketLength . fromIntegral $ BL.length bs
-    putLazyByteString bs
+    putLengthThenPayload bs
 putPkt (SecretKeyPkt pkp ska) = do
     putWord8 (0xc0 .|. 5)
     let bs = runPut (putPKPayload pkp >> putSKAddendum ska)
-    putPacketLength . fromIntegral $ BL.length bs
-    putLazyByteString bs
+    putLengthThenPayload bs
 putPkt (PublicKeyPkt pkp) = do
     putWord8 (0xc0 .|. 6)
     let bs = runPut $ putPKPayload pkp
-    putPacketLength . fromIntegral $ BL.length bs
-    putLazyByteString bs
+    putLengthThenPayload bs
 putPkt (SecretSubkeyPkt pkp ska) = do
     putWord8 (0xc0 .|. 7)
     let bs = runPut (putPKPayload pkp >> putSKAddendum ska)
-    putPacketLength . fromIntegral $ BL.length bs
-    putLazyByteString bs
+    putLengthThenPayload bs
 putPkt (CompressedDataPkt ca cdata) = do
     putWord8 (0xc0 .|. 8)
     let bs = runPut $ do
                          putWord8 $ fromIntegral . fromFVal $ ca
                          putLazyByteString cdata
-    putPacketLength . fromIntegral $ BL.length bs
-    putLazyByteString bs
+    putLengthThenPayload bs
 putPkt (SymEncDataPkt b) = do
     putWord8 (0xc0 .|. 9)
-    putPacketLength . fromIntegral $ BL.length b
-    putLazyByteString b
+    putLengthThenPayload b
 putPkt (MarkerPkt b) = do
     putWord8 (0xc0 .|. 10)
-    putPacketLength . fromIntegral $ BL.length b
-    putLazyByteString b
+    putLengthThenPayload b
 putPkt (LiteralDataPkt dt fn ts b) = do
     putWord8 (0xc0 .|. 11)
     let bs = runPut $ do
@@ -729,12 +715,10 @@ putPkt (LiteralDataPkt dt fn ts b) = do
                         putLazyByteString fn
                         putWord32be . unThirtyTwoBitTimeStamp $ ts
                         putLazyByteString b
-    putPacketLength . fromIntegral $ BL.length bs
-    putLazyByteString bs
+    putLengthThenPayload bs
 putPkt (TrustPkt b) = do
     putWord8 (0xc0 .|. 12)
-    putPacketLength . fromIntegral . BL.length $ b
-    putLazyByteString b
+    putLengthThenPayload b
 putPkt (UserIdPkt u) = do
     putWord8 (0xc0 .|. 13)
     let bs = encodeUtf8 u
@@ -743,13 +727,11 @@ putPkt (UserIdPkt u) = do
 putPkt (PublicSubkeyPkt pkp) = do
     putWord8 (0xc0 .|. 14)
     let bs = runPut $ putPKPayload pkp
-    putPacketLength . fromIntegral $ BL.length bs
-    putLazyByteString bs
+    putLengthThenPayload bs
 putPkt (UserAttributePkt us) = do
     putWord8 (0xc0 .|. 17)
     let bs = runPut $ mapM_ put us
-    putPacketLength . fromIntegral $ BL.length bs
-    putLazyByteString bs
+    putLengthThenPayload bs
 putPkt (SymEncIntegrityProtectedDataPkt pv b) = do
     putWord8 (0xc0 .|. 18)
     putPacketLength . fromIntegral $ BL.length b + 1
@@ -757,14 +739,17 @@ putPkt (SymEncIntegrityProtectedDataPkt pv b) = do
     putLazyByteString b
 putPkt (ModificationDetectionCodePkt hash) = do
     putWord8 (0xc0 .|. 19)
-    putPacketLength . fromIntegral . BL.length $ hash
-    putLazyByteString hash
+    putLengthThenPayload hash
 putPkt (OtherPacketPkt t payload) = do
     putWord8 (0xc0 .|. t) -- FIXME: restrict t
-    putPacketLength . fromIntegral . BL.length $ payload
-    putLazyByteString payload
+    putLengthThenPayload payload
 putPkt (BrokenPacketPkt _ t payload) = putPkt (OtherPacketPkt t payload)
 
+putLengthThenPayload :: ByteString -> Put
+putLengthThenPayload bs = do
+    putPacketLength . fromIntegral $ BL.length bs
+    putLazyByteString bs
+
 getMPI :: Get MPI
 getMPI = do mpilen <- getWord16be
             bs <- getLazyByteString (fromIntegral (mpilen + 7) `div` 8)
@@ -786,7 +771,7 @@ getPubkey ForbiddenElgamal = do MPI p <- get
                                 MPI g <- get
                                 MPI y <- get
                                 return $ ElGamalPubKey [p,g,y]
-getPubkey _ = UnknownPKey <$> (getLazyByteString =<< remaining)
+getPubkey _ = UnknownPKey <$> getRemainingLazyByteString
 
 putPubkey :: PKey -> Put
 putPubkey (UnknownPKey bs) = put bs
@@ -799,8 +784,7 @@ getSecretKey pkp
            MPI p <- get
            MPI q <- get
            MPI _ <- get -- u
-           let n = p * q
-               dP = 0
+           let dP = 0
                dQ = 0
                qinv = 0
                pub = (\(RSAPubKey (RSA_PublicKey x)) -> x) (pkp^.pubkey)
@@ -861,8 +845,7 @@ getSKAddendum pkp = do
                       OtherS2K _ _ -> return $ SUS16bit (toFVal symenc) s2k mempty BL.empty
                       _ -> do
                               iv <- getByteString (symEncBlockSize . toFVal $ symenc)
-                              remainder <- remaining
-                              encryptedblock <- getLazyByteString remainder
+                              encryptedblock <- getRemainingLazyByteString
                               return $ SUS16bit (toFVal symenc) s2k (IV iv) encryptedblock
         254 -> do symenc <- getWord8
                   s2k <- getS2K
@@ -870,12 +853,10 @@ getSKAddendum pkp = do
                       OtherS2K _ _ -> return $ SUSSHA1 (toFVal symenc) s2k mempty BL.empty
                       _ -> do
                               iv <- getByteString (symEncBlockSize . toFVal $ symenc)
-                              remainder <- remaining
-                              encryptedblock <- getLazyByteString remainder
+                              encryptedblock <- getRemainingLazyByteString
                               return $ SUSSHA1 (toFVal symenc) s2k (IV iv) encryptedblock
         symenc -> do iv <- getByteString (symEncBlockSize . toFVal $ symenc)
-                     remainder <- remaining
-                     encryptedblock <- getLazyByteString remainder
+                     encryptedblock <- getRemainingLazyByteString
                      return $ SUSym (toFVal symenc) (IV iv) encryptedblock
 
 putSKAddendum :: SKAddendum -> Put
@@ -1178,8 +1159,7 @@ getSignaturePayload = do
             pka <- get
             ha <- get
             left16 <- getWord16be
-            remainder <- remaining
-            mpib <- getLazyByteString remainder
+            mpib <- getRemainingLazyByteString
             case runGetOrFail (some getMPI) mpib of
                 Left (_, _, e) -> fail ("v3 sig MPIs " ++ e)
                 Right (_, _, mpis) -> return $ SigV3 (toFVal st) ctime (EightOctetKeyId eok) (toFVal pka) (toFVal ha) left16 (NE.fromList mpis)
@@ -1198,14 +1178,12 @@ getSignaturePayload = do
                             Left (_, _, err) -> fail ("v4 sig unhasheds " ++ err)
                             Right (_, _, u) -> u
             left16 <- getWord16be
-            remainder <- remaining
-            mpib <- getLazyByteString remainder
+            mpib <- getRemainingLazyByteString
             case runGetOrFail (some getMPI) mpib of
                     Left (_, _, e) -> fail ("v4 sig MPIs " ++ e)
                     Right (_, _, mpis) -> return $ SigV4 (toFVal st) (toFVal pka) (toFVal ha) hashed unhashed left16 (NE.fromList mpis)
         _ -> do
-            remainder <- remaining
-            bs <- getLazyByteString remainder
+            bs <- getRemainingLazyByteString
             return $ SigVOther pv bs
 
 putSignaturePayload :: SignaturePayload -> Put
