@@ -1,5 +1,5 @@
 -- SerializeForSigs.hs: OpenPGP (RFC4880) special serialization for signature purposes
--- Copyright © 2012-2014  Clint Adams
+-- Copyright © 2012-2015  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -16,11 +16,11 @@ module Codec.Encryption.OpenPGP.SerializeForSigs (
 ) where
 
 import Control.Lens ((^.))
-import Data.ByteString (ByteString)
+import Data.ByteString.Lazy (ByteString)
 import qualified Data.ByteString as B
-import Data.Serialize (Serialize, put)
-import Data.Serialize.Put (Put, putWord8, putWord16be, putWord32be, putByteString, runPut)
-import qualified Data.Text as T
+import qualified Data.ByteString.Lazy as BL
+import Data.Binary (Binary, put)
+import Data.Binary.Put (Put, putWord8, putWord16be, putWord32be, putByteString, putLazyByteString, runPut)
 import Data.Text.Encoding (encodeUtf8)
 
 import Codec.Encryption.OpenPGP.Internal (PktStreamContext(..), integerToBEBS, pubkeyToMPIs)
@@ -32,12 +32,12 @@ putPKPforFingerprinting (PublicKeyPkt (PKPayload DeprecatedV3 _ _ _ pk)) = mapM_
 putPKPforFingerprinting (PublicKeyPkt pkp@(PKPayload V4 _ _ _ _)) = do
     putWord8 0x99
     let bs = runPut $ put pkp
-    putWord16be . fromIntegral $ B.length bs
-    putByteString bs
+    putWord16be . fromIntegral $ BL.length bs
+    putLazyByteString bs
 putPKPforFingerprinting _ = fail "This should never happen (putPKPforFingerprinting)"
 
 putMPIforFingerprinting:: MPI -> Put
-putMPIforFingerprinting(MPI i) = let bs = integerToBEBS i in putByteString bs
+putMPIforFingerprinting(MPI i) = let bs = integerToBEBS i in putLazyByteString bs
 
 putPartialSigforSigning :: Pkt -> Put
 putPartialSigforSigning (SignaturePkt (SigV4 st pka ha hashed _ _ _)) = do
@@ -46,15 +46,15 @@ putPartialSigforSigning (SignaturePkt (SigV4 st pka ha hashed _ _ _)) = do
     put pka
     put ha
     let hb = runPut $ mapM_ put hashed
-    putWord16be . fromIntegral . B.length $ hb
-    putByteString hb
+    putWord16be . fromIntegral . BL.length $ hb
+    putLazyByteString hb
 putPartialSigforSigning _ = fail "This should never happen (putPartialSigforSigning)"
 
 putSigTrailer :: Pkt -> Put
 putSigTrailer (SignaturePkt (SigV4 _ _ _ hs _ _ _)) = do
             putWord8 0x04
             putWord8 0xff
-            putWord32be . fromIntegral . (+6) . B.length $ runPut $ mapM_ put hs
+            putWord32be . fromIntegral . (+6) . BL.length $ runPut $ mapM_ put hs
             -- this +6 seems like a bug in RFC4880
 putSigTrailer _ = fail "This should never happen (putSigTrailer)"
 
@@ -66,7 +66,7 @@ putUforSigning _ = fail "This should never happen (putUforSigning)"
 putUIDforSigning :: Pkt -> Put
 putUIDforSigning (UserIdPkt u) = do
     putWord8 0xB4
-    let bs = encodeUtf8 . T.pack $ u
+    let bs = encodeUtf8 u
     putWord32be . fromIntegral . B.length $ bs
     putByteString bs
 putUIDforSigning _ = fail "This should never happen (putUIDforSigning)"
@@ -75,16 +75,16 @@ putUAtforSigning :: Pkt -> Put
 putUAtforSigning (UserAttributePkt us) = do
     putWord8 0xD1
     let bs = runPut (mapM_ put us)
-    putWord32be . fromIntegral . B.length $ bs
-    putByteString bs
+    putWord32be . fromIntegral . BL.length $ bs
+    putLazyByteString bs
 putUAtforSigning _ = fail "This should never happen (putUAtforSigning)"
 
 putSigforSigning :: Pkt -> Put
 putSigforSigning (SignaturePkt (SigV4 st pka ha hashed _ left16 mpis)) = do
     putWord8 0x88
     let bs = runPut $ put (SigV4 st pka ha hashed [] left16 mpis)
-    putWord32be . fromIntegral . B.length $ bs
-    putByteString bs
+    putWord32be . fromIntegral . BL.length $ bs
+    putLazyByteString bs
 putSigforSigning _ = fail "Non-V4 not implemented."
 
 putKeyforSigning :: Pkt -> Put
@@ -98,13 +98,13 @@ putKeyForSigning' :: PKPayload -> Put
 putKeyForSigning' pkp = do
     putWord8 0x99
     let bs = runPut $ put pkp
-    putWord16be . fromIntegral . B.length $ bs
-    putByteString bs
+    putWord16be . fromIntegral . BL.length $ bs
+    putLazyByteString bs
 
 payloadForSig :: SigType -> PktStreamContext -> ByteString
 payloadForSig BinarySig state = fromPkt (lastLD state)^.literalDataPayload
 payloadForSig CanonicalTextSig state = payloadForSig BinarySig state
-payloadForSig StandaloneSig _ = B.empty
+payloadForSig StandaloneSig _ = BL.empty
 payloadForSig GenericCert state = kandUPayload (lastPrimaryKey state) (lastUIDorUAt state)
 payloadForSig PersonaCert state = payloadForSig GenericCert state
 payloadForSig CasualCert state = payloadForSig GenericCert state
