@@ -23,8 +23,8 @@ import Data.ByteString.Lazy (ByteString)
 import qualified Data.ByteString as B
 import qualified Data.ByteString.Lazy as BL
 import Data.Either (lefts, rights)
-import Data.IxSet ((@=))
-import qualified Data.IxSet as IxSet
+import Data.IxSet.Typed ((@=))
+import qualified Data.IxSet.Typed as IxSet
 import Data.List.NonEmpty (NonEmpty(..))
 import Data.Text (Text)
 import Data.Time.Clock (UTCTime(..), diffUTCTime)
