@@ -3,6 +3,7 @@
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
+{-# LANGUAGE DataKinds #-}
 {-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE DeriveGeneric #-}
 {-# LANGUAGE ExistentialQuantification #-}
@@ -32,7 +33,7 @@ import qualified Data.ByteString.Lazy as BL
 import Data.Char (toLower, toUpper)
 import Data.Data (Data)
 import Data.Hashable (Hashable(..))
-import Data.IxSet (IxSet)
+import Data.IxSet.Typed (IxSet)
 import Data.List (unfoldr)
 import Data.List.NonEmpty (NonEmpty)
 import qualified Data.List.NonEmpty as NE
@@ -50,7 +51,7 @@ import Data.Typeable (Typeable)
 import Data.Word (Word8, Word16, Word32)
 import Network.URI (URI(..), uriToString, nullURI, parseURI)
 import Numeric (readHex, showHex)
-import System.Locale (defaultTimeLocale)
+import Data.Time.Locale.Compat (defaultTimeLocale)
 import Text.PrettyPrint.Free (Pretty(..), (<+>), char, hsep, punctuate, space, text, tupled)
 
 type Exportability = Bool
@@ -1197,7 +1198,8 @@ instance Ord TK where
 
 instance A.ToJSON TK
 
-type Keyring = IxSet TK
+type KeyringIxs = '[EightOctetKeyId, TwentyOctetFingerprint, Text]
+type Keyring = IxSet KeyringIxs TK
 
 class Packet a where
     data PacketType a :: *
