@@ -15,7 +15,7 @@ import Codec.Encryption.OpenPGP.Types
 import Codec.Encryption.OpenPGP.Signatures (verifySigWith, verifyAgainstKeyring)
 import qualified Data.Conduit.List as CL
 
-conduitVerify :: MonadResource m => Keyring -> Maybe UTCTime -> Conduit Pkt m (Either String Verification)
+conduitVerify :: Monad m => Keyring -> Maybe UTCTime -> Conduit Pkt m (Either String Verification)
 conduitVerify kr mt = CL.concatMapAccum (flip push) emptyPSC
     where
         push state ld@(LiteralDataPkt {}) = (state { lastLD = ld }, [])
