@@ -29,7 +29,7 @@ import Data.Conduit.OpenPGP.Compression (conduitCompress, conduitDecompress)
 import Data.Conduit.OpenPGP.Decrypt (conduitDecrypt)
 import Data.Conduit.OpenPGP.Keyring (conduitToTKs, conduitToTKsDropping, sinkKeyringMap)
 import Data.Conduit.OpenPGP.Verify (conduitVerify)
-import Data.IxSet ((@=), getOne)
+import Data.IxSet.Typed ((@=), getOne)
 import Data.Maybe (isJust)
 import Data.Binary (get, put)
 import Data.Binary.Get (runGetOrFail, Get)
